import { axisLeft,
        area,
        axisBottom,
        select,
        csv,
        max,
        format,
        curveBasis,
        extent,
        scaleTime,
        scaleLinear         
        } from 'd3';

const svg = select('svg');
const div = select("body").append("div").attr("class", "tooltip");

const width = +svg.attr('width');
const height = +svg.attr('height');

// RENDER FUNCTION
const render = data => {
  const title = "World Population";
  const yValue = d => d.population
  const yAxisLabel = "Population";
  const xValue = d => d.year
  const xAxisLabel = "Time";
  const circleRadius = 6;
  
  const margin = {top:40,right:40, bottom:75, left:120}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  // SCALES
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();  
  const yScale = scaleLinear()
  	.domain([0,max(data, yValue)])
  	.range([innerHeight,0])
    .nice();
  	
  // GROUP
  const g = svg.append("g")
  	.attr("transform", "translate("+margin.left+","+margin.top+")")
    
  
  const xAxis =axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.ticks(6)
  	.tickPadding(20);
  
  const yAxisTickFormat = number =>
  	format(".1s")(number)
  		.replace("G","B")
  		
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
  	.tickFormat(yAxisTickFormat);
  
  // Y AXIS GROUP
  const yAxisG = g.append("g").call(yAxis)
  yAxisG.selectAll(".domain").remove();
  // Y AXIS LABEL
  yAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr("y", -70)
  	.attr("x", -innerHeight/2)
  	.attr("fill","black")
    .attr("transform", "rotate(-90)")
  	.attr("text-anchor", "middle")
  	.text(yAxisLabel);
  
  // X AXIS GROUP
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", "translate(0,"+innerHeight+")")
  
  xAxisG.select(".domain").remove();
  // X AXIS LABEL
  xAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr("y", 65)
  	.attr("x", innerWidth/2)
  	.attr("fill","black")
  	.text(xAxisLabel);
  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append("path")
  	.attr("class", "line-path")
  	.attr("stroke", "black")
  	.attr("d", areaGenerator(data))
  
  //TITLE   
  svg.append("text")
  	.attr("x", width / 2 )
  	.attr("y", 35)
  	.attr("class", "title")
    .text(title);
   
}  

//GETTING DATA FROM CSV and PARSING
csv("https://vizhub.com/curran/datasets/world-population-by-year-2015.csv")
  .then(data=>{
  	data.forEach(d=>{
      d.year = new Date(d.year);
      d.population = +d.population
  })
    render(data)
})